==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/tr.php <==
<?php

return [
    'Names' => [
        'Afak' => 'Afaka',
        'Aghb' => 'Kafkas Albanyası',
        'Arab' => 'Arap',
        'Aran' => 'Nestâlik',
        'Armi' => 'İmparatorluk Aramicesi',
        'Armn' => 'Ermeni',
        'Avst' => 'Avesta',
        'Bali' => 'Bali Dili',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Bengal',
        'Blis' => 'Blis Sembolleri',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Braille',
        'Bugi' => 'Bugis',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'UCAS',
        'Cari' => 'Karya',
        'Cham' => 'Cham',
        'Cher' => 'Çeroki',
        'Cirt' => 'Cirth',
        'Copt' => 'Kıpti',
        'Cprt' => 'Kıbrıs',
        'Cyrl' => 'Kiril',
        'Cyrs' => 'Eski Kilise Slavcası Kiril',
        'Deva' => 'Devanagari',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployé Stenografi',
        'Egyd' => 'Demotik Mısır',
        'Egyh' => 'Hiyeratik Mısır',
        'Egyp' => 'Mısır Hiyeroglifleri',
        'Elba' => 'Elbasan',
        'Ethi' => 'Etiyopya',
        'Geok' => 'Hutsuri Gürcü',
        'Geor' => 'Gürcü',
        'Glag' => 'Glagolit',
        'Goth' => 'Gotik',
        'Gran' => 'Grantha',
        'Grek' => 'Yunan',
        'Gujr' => 'Gücerat',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han - Bopomofo',
        'Hang' => 'Hangıl',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'Basitleştirilmiş',
        'Hant' => 'Geleneksel',
        'Hebr' => 'İbrani',
        'Hira' => 'Hiragana',
        'Hluw' => 'Anadolu Hiyeroglifleri',
        'Hmng' => 'Pahavh Hmong',
        'Hrkt' => 'Japon hece alfabeleri',
        'Hung' => 'Eski Macar',
        'Inds' => 'Indus',
        'Ital' => 'Eski İtalyan',
        'Jamo' => 'Jamo',
        'Java' => 'Cava Dili',
        'Jpan' => 'Japon',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Kmer',
        'Khoj' => 'Khojki',
        'Knda' => 'Kannada',
        'Kore' => 'Korece',
        'Kpel' => 'Kpelle',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Lao',
        'Latf' => 'Fraktur Latin',
        'Latg' => 'Gael Latin',
        'Latn' => 'Latin',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Lineer A',
        'Linb' => 'Lineer B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Likya',
        'Lydi' => 'Lidya',
        'Mahj' => 'Mahajani',
        'Mand' => 'Manden',
        'Maya' => 'Maya Hiyeroglifleri',
        'Mend' => 'Mende',
        'Merc' => 'Meroitik El Yazısı',
        'Mero' => 'Meroitik',
        'Mlym' => 'Malayalam',
        'Modi' => 'Modi',
        'Mong' => 'Moğol',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Burma',
        'Narb' => 'Eski Kuzey Arap',
        'Nbat' => 'Nebati',
        'Nkgb' => 'Naksi Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orhun',
        'Orya' => 'Oriya',
        'Osma' => 'Osmanya',
        'Palm' => 'Palmira',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Eski Permik',
        'Phag' => 'Phags-pa',
        'Phli' => 'Pehlevi Kitabe Dili',
        'Phlp' => 'Psalter Pehlevi',
        'Phlv' => 'Kitap Pehlevi Dili',
        'Phnx' => 'Fenike',
        'Plrd' => 'Pollard Fonetik',
        'Prti' => 'Partça Kitabe Dili',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runik',
        'Samr' => 'Samarit',
        'Sara' => 'Sarati',
        'Sarb' => 'Eski Güney Arap',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'İşaret Dili',
        'Shaw' => 'Shavian',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudabadi',
        'Sinh' => 'Seylan',
        'Sora' => 'Sora Sompeng',
        'Sund' => 'Sunda',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Süryani',
        'Syre' => 'Estrangela Süryani',
        'Syrj' => 'Batı Süryani',
        'Syrn' => 'Doğu Süryani',
        'Tagb' => 'Tagbanva',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'New Tai Lue',
        'Taml' => 'Tamil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengvar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Takalot',
        'Thaa' => 'Thaana',
        'Thai' => 'Tay',
        'Tibt' => 'Tibet',
        'Tirh' => 'Tirhuta',
        'Ugar' => 'Ugarit Çivi Yazısı',
        'Vaii' => 'Vai',
        'Visp' => 'Konuşma Sesleri Çizimlemesi',
        'Wara' => 'Varang Kshiti',
        'Wole' => 'Woleai',
        'Xpeo' => 'Eski Fars',
        'Xsux' => 'Sümer-Akad Çivi Yazısı',
        'Yiii' => 'Yi',
        'Zinh' => 'Kalıtsal',
        'Zmth' => 'Matematiksel Gösterim',
        'Zsye' => 'Emoji',
        'Zsym' => 'Sembol',
        'Zxxx' => 'Yazılı Olmayan',
        'Zyyy' => 'Ortak',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/scripts/tr.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Afaka',
        'Aghb' => 'Kafkas Albanyası',
        'Arab' => 'Arap',
        'Aran' => 'Nestâlik',
        'Armi' => 'İmparatorluk Aramicesi',
        'Armn' => 'Ermeni',
        'Avst' => 'Avesta',
        'Bali' => 'Bali Dili',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Bengal',
        'Blis' => 'Blis Sembolleri',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Braille',
        'Bugi' => 'Bugis',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'UCAS',
        'Cari' => 'Karya',
        'Cham' => 'Cham',
        'Cher' => 'Çeroki',
        'Cirt' => 'Cirth',
        'Copt' => 'Kıpti',
        'Cprt' => 'Kıbrıs',
        'Cyrl' => 'Kiril',
        'Cyrs' => 'Eski Kilise Slavcası Kiril',
        'Deva' => 'Devanagari',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployé Stenografi',
        'Egyd' => 'Demotik Mısır',
        'Egyh' => 'Hiyeratik Mısır',
        'Egyp' => 'Mısır Hiyeroglifleri',
        'Elba' => 'Elbasan',
        'Ethi' => 'Etiyopya',
        'Geok' => 'Hutsuri Gürcü',
        'Geor' => 'Gürcü',
        'Glag' => 'Glagolit',
        'Goth' => 'Gotik',
        'Gran' => 'Grantha',
        'Grek' => 'Yunan',
        'Gujr' => 'Gücerat',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han - Bopomofo',
        'Hang' => 'Hangıl',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'Basitleştirilmiş',
        'Hant' => 'Geleneksel',
        'Hebr' => 'İbrani',
        'Hira' => 'Hiragana',
        'Hluw' => 'Anadolu Hiyeroglifleri',
        'Hmng' => 'Pahavh Hmong',
        'Hrkt' => 'Japon hece alfabeleri',
        'Hung' => 'Eski Macar',
        'Inds' => 'Indus',
        'Ital' => 'Eski İtalyan',
        'Jamo' => 'Jamo',
        'Java' => 'Cava Dili',
        'Jpan' => 'Japon',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Kmer',
        'Khoj' => 'Khojki',
        'Knda' => 'Kannada',
        'Kore' => 'Korece',
        'Kpel' => 'Kpelle',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Lao',
        'Latf' => 'Fraktur Latin',
        'Latg' => 'Gael Latin',
        'Latn' => 'Latin',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Lineer A',
        'Linb' => 'Lineer B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Likya',
        'Lydi' => 'Lidya',
        'Mahj' => 'Mahajani',
        'Mand' => 'Manden',
        'Maya' => 'Maya Hiyeroglifleri',
        'Mend' => 'Mende',
        'Merc' => 'Meroitik El Yazısı',
        'Mero' => 'Meroitik',
        'Mlym' => 'Malayalam',
        'Modi' => 'Modi',
        'Mong' => 'Moğol',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Burma',
        'Narb' => 'Eski Kuzey Arap',
        'Nbat' => 'Nebati',
        'Nkgb' => 'Naksi Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orhun',
        'Orya' => 'Oriya',
        'Osma' => 'Osmanya',
        'Palm' => 'Palmira',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Eski Permik',
        'Phag' => 'Phags-pa',
        'Phli' => 'Pehlevi Kitabe Dili',
        'Phlp' => 'Psalter Pehlevi',
        'Phlv' => 'Kitap Pehlevi Dili',
        'Phnx' => 'Fenike',
        'Plrd' => 'Pollard Fonetik',
        'Prti' => 'Partça Kitabe Dili',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runik',
        'Samr' => 'Samarit',
        'Sara' => 'Sarati',
        'Sarb' => 'Eski Güney Arap',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'İşaret Dili',
        'Shaw' => 'Shavian',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudabadi',
        'Sinh' => 'Seylan',
        'Sora' => 'Sora Sompeng',
        'Sund' => 'Sunda',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Süryani',
        'Syre' => 'Estrangela Süryani',
        'Syrj' => 'Batı Süryani',
        'Syrn' => 'Doğu Süryani',
        'Tagb' => 'Tagbanva',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'New Tai Lue',
        'Taml' => 'Tamil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengvar',
        'Tfng' => 'Tifinag',
        'Tglg' => 'Takalot',
        'Thaa' => 'Thaana',
        'Thai' => 'Tay',
        'Tibt' => 'Tibet',
        'Tirh' => 'Tirhuta',
        'Ugar' => 'Ugarit Çivi Yazısı',
        'Vaii' => 'Vai',
        'Visp' => 'Konuşma Sesleri Çizimlemesi',
        'Wara' => 'Varang Kshiti',
        'Wole' => 'Woleai',
        'Xpeo' => 'Eski Fars',
        'Xsux' => 'Sümer-Akad Çivi Yazısı',
        'Yiii' => 'Yi',
        'Zinh' => 'Kalıtsal',
        'Zmth' => 'Matematiksel Gösterim',
        'Zsye' => 'Emoji',
        'Zsym' => 'Sembol',
        'Zxxx' => 'Yazılı Olmayan',
        'Zyyy' => 'Ortak',
    ],
];
